Skip to contents

Computes expression-weighted centered scaled ranks for a sparse or dense expression matrix, calculated per column (cell).

Usage

ewcsr.sparse(mat)

Arguments

mat

A matrix with features (genes) as rows and cells or samples as columns.

Value

A matrix of EWCSR-transformed values with the same dimensions as mat.

Details

EWCSR transformation emphasizes relatively high and low expression features within each cell while accounting for expression magnitude. The output matrix retains the same dimensions as the input.

Examples

if (FALSE) { # \dontrun{
ewcsr_mat <- ewcsr.sparse(mat)
} # }